==> haskell-regex-pcre-0.95.0.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-pcre
version:              0.95.0.0
visibility:           public
id:                   regex-pcre-0.95.0.0-AbiU1MQKy02IJzVPRbhoWZ
key:                  regex-pcre-0.95.0.0-AbiU1MQKy02IJzVPRbhoWZ
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             PCRE Backend for "Text.Regex" (regex-base)
description:
    This package provides a <http://pcre.org/ PCRE> backend for the <//hackage.haskell.org/package/regex-base regex-base> API.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  3eb23857d25a535f7cb4b56058d79807
exposed:              True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap

hidden-modules:       Paths_regex_pcre
import-dirs:          /usr/lib/ghc-8.10.4/site-local/regex-pcre-0.95.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/regex-pcre-0.95.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/regex-pcre-0.95.0.0
hs-libraries:         HSregex-pcre-0.95.0.0-AbiU1MQKy02IJzVPRbhoWZ
extra-libraries:      pcre
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    regex-base-0.94.0.1-61S2JIUUNzk1MaMYHGGdFS

haddock-interfaces:   /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html:         /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-pcre-0.95.0.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-pcre
version:              0.95.0.0
visibility:           public
id:                   regex-pcre-0.95.0.0-kvOmAUElA0Awn0KOn2hcm
key:                  regex-pcre-0.95.0.0-kvOmAUElA0Awn0KOn2hcm
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             PCRE Backend for "Text.Regex" (regex-base)
description:
    This package provides a <http://pcre.org/ PCRE> backend for the <//hackage.haskell.org/package/regex-base regex-base> API.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  d5e9416d21be27788e9027d69e568655
exposed:              True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap

hidden-modules:       Paths_regex_pcre
import-dirs:          /usr/lib/ghc-9.0.1/site-local/regex-pcre-0.95.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/regex-pcre-0.95.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/regex-pcre-0.95.0.0
hs-libraries:         HSregex-pcre-0.95.0.0-kvOmAUElA0Awn0KOn2hcm
extra-libraries:      pcre
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    regex-base-0.94.0.1-ApKWahF5a61J2tR7Doeu1C

haddock-interfaces:   /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html:         /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
